==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1NonResourceAttributesFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1NonResourceAttributesFluentImpl<A extends V1NonResourceAttributesFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1NonResourceAttributesFluent<A>{

    private String path;
    private String verb;

    public V1NonResourceAttributesFluentImpl(){
    }
    public V1NonResourceAttributesFluentImpl(V1NonResourceAttributes instance){
            this.withPath(instance.getPath());

            this.withVerb(instance.getVerb());

    }

    public String getPath(){
            return this.path;
    }

    public A withPath(String path){
            this.path=path; return (A) this;
    }

    public Boolean hasPath(){
            return this.path != null;
    }

    public String getVerb(){
            return this.verb;
    }

    public A withVerb(String verb){
            this.verb=verb; return (A) this;
    }

    public Boolean hasVerb(){
            return this.verb != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1NonResourceAttributesFluentImpl that = (V1NonResourceAttributesFluentImpl) o;
            if (path != null ? !path.equals(that.path) :that.path != null) return false;
            if (verb != null ? !verb.equals(that.verb) :that.verb != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1NonResourceAttributesFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1NonResourceAttributesFluentImpl<A extends V1NonResourceAttributesFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1NonResourceAttributesFluent<A>{

    private String path;
    private String verb;

    public V1NonResourceAttributesFluentImpl(){
    }
    public V1NonResourceAttributesFluentImpl(V1NonResourceAttributes instance){
            this.withPath(instance.getPath());

            this.withVerb(instance.getVerb());

    }

    public String getPath(){
            return this.path;
    }

    public A withPath(String path){
            this.path=path; return (A) this;
    }

    public Boolean hasPath(){
            return this.path != null;
    }

    public A withNewPath(String arg1){
            return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuilder arg1){
            return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuffer arg1){
            return (A)withPath(new String(arg1));
    }

    public String getVerb(){
            return this.verb;
    }

    public A withVerb(String verb){
            this.verb=verb; return (A) this;
    }

    public Boolean hasVerb(){
            return this.verb != null;
    }

    public A withNewVerb(String arg1){
            return (A)withVerb(new String(arg1));
    }

    public A withNewVerb(StringBuilder arg1){
            return (A)withVerb(new String(arg1));
    }

    public A withNewVerb(StringBuffer arg1){
            return (A)withVerb(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1NonResourceAttributesFluentImpl that = (V1NonResourceAttributesFluentImpl) o;
            if (path != null ? !path.equals(that.path) :that.path != null) return false;
            if (verb != null ? !verb.equals(that.verb) :that.verb != null) return false;
            return true;
    }




}
